#
# spec file for package gnome-multi-writer
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           gnome-multi-writer
Version:        3.35.90+26
Release:        1.4
Summary:        Program for writing an ISO file to multiple USB devices at once
License:        GPL-2.0-or-later
Group:          System/GUI/GNOME
URL:            https://wiki.gnome.org/Apps/MultiWriter
Source0:        %{name}-%{version}.tar.zst
BuildRequires:  docbook-utils-minimal
BuildRequires:  gobject-introspection-devel >= 0.9.8
BuildRequires:  hicolor-icon-theme
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  yelp-tools
BuildRequires:  pkgconfig(gio-2.0) >= 2.25.9
BuildRequires:  pkgconfig(glib-2.0) >= 2.45.8
BuildRequires:  pkgconfig(gmodule-2.0)
BuildRequires:  pkgconfig(gobject-2.0)
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.11.2
BuildRequires:  pkgconfig(gudev-1.0)
BuildRequires:  pkgconfig(gusb) >= 0.2.7
BuildRequires:  pkgconfig(libcanberra-gtk3) >= 0.10
BuildRequires:  pkgconfig(polkit-gobject-1)
BuildRequires:  pkgconfig(udisks2)

%description
GNOME MultiWriter can be used to write an ISO file to multiple USB devices
at once.
Supported drive sizes are between 1Gb and 32Gb.

MultiWriter may be useful for QA testing, to create a GNOME Live image
or a code sprint or to create hundreds of LiveUSB drives for a trade show.

%lang_package

%prep
%autosetup -p1

%build
%meson
%meson_build

%install
%meson_install
%find_lang %{name} %{?no_lang_C}
%suse_update_desktop_file org.gnome.MultiWriter Filesystem X-GNOME-Utilities

%files
%license COPYING
%{_bindir}/%{name}
%{_libexecdir}/gnome-multi-writer-probe
%{_datadir}/glib-2.0/schemas/org.gnome.MultiWriter.gschema.xml
%{_datadir}/applications/org.gnome.MultiWriter.desktop
%{_datadir}/icons/hicolor/*/apps/org.gnome.MultiWriter*
%{_datadir}/metainfo/org.gnome.MultiWriter.appdata.xml
# Just own these dirs, no need to buildrequire polkit
%dir %{_datadir}/polkit-1
%dir %{_datadir}/polkit-1/actions
%{_datadir}/polkit-1/actions/org.gnome.MultiWriter.policy
%{_mandir}/man1/gnome-multi-writer.1%{?ext_man}

%files lang -f %{name}.lang

%changelog
* Fri Oct 13 2023 bjorn.lie@gmail.com
- Update to version 3.35.90+26:
  * Updated translations.
- Switch to git checkout via source service, explicit commit.
* Wed Mar  4 2020 bjorn.lie@gmail.com
- Update to version 3.35.90:
  + This unstable release fixes the following bug: Fix gmw-probe
    only testing the first 15%% of the disks.
  + Updated translations.
* Sat Jan 25 2020 Dominique Leuenberger <dimstar@opensuse.org>
- No longer recommend -lang: supplements are in use
* Wed May 22 2019 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 3.32.1:
  + This fixes a memory corruption issue causing the UI to crash
    and also fixes some build issues.
* Thu Apr 18 2019 Jan Engelhardt <jengelh@inai.de>
- Use noun phrase in summary.
* Fri Mar  8 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.32.0:
  + Use newer meson features to avoid a build warning.
  + Various C99 cleanups.
  + Use G_DECLARE_FINAL_TYPE for GmwDevice.
  + Remove the AppMenu.
  + Updated translations.
- Drop patches fixed upstream:
  + gnome-multi-writer-Various-C99-cleanups.patch.
  + gnome-multi-writer-Use-G_DECLARE_FINAL_TYPE.patch.
* Fri Dec 28 2018 bjorn.lie@gmail.com
- Add upstream bug fix patches from stable branch:
  + gnome-multi-writer-Various-C99-cleanups.patch: Various C99
    cleanups.
  + gnome-multi-writer-Use-G_DECLARE_FINAL_TYPE.patch: Use
    G_DECLARE_FINAL_TYPE for GmwDevice.
* Fri Sep  7 2018 bjorn.lie@gmail.com
- Update to version 3.30.0:
  + Updated translations.
* Mon Mar 12 2018 dimstar@opensuse.org
- Update to version 3.28.0:
  + Updated translations.
- Drop gnome-multi-writer-meson.patch,
  gmw-norwegian-bokmaal-translation.patch and
  gmw-gschema-fix-gettext-domain.patch: fixed upstream.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Fri Dec 22 2017 zaitor@opensuse.org
- Add gmw-gschema-fix-gettext-domain.patch: gschema: Fix
  gettext-domain.
- Add gmw-norwegian-bokmaal-translation.patch: Add Norwegian Bokmål
  translations.
* Mon Sep 11 2017 dimstar@opensuse.org
- Update to version 3.26.0:
  + Updated translations.
* Tue Aug 15 2017 dimstar@opensuse.org
- Update to version 3.25.90:
  + Switch to meson build system.
  + Updated translations.
- Add meson BuildRequires and switch autotools macros configure,
  make and makeinstall to meson, meson_build and meson_install
  following upstream switch to Meson build system.
- Add gnome-multi-writer-meson.patch: respect --libexecdir meson
  parameter.
* Mon Mar 20 2017 dimstar@opensuse.org
- Update to version 3.24.0:
  + No changes.
* Sat Mar 11 2017 dimstar@opensuse.org
- Update to version 3.23.92:
  + Check some return codes when talking to the device.
  + Updated translations.
* Wed Oct 12 2016 zaitor@opensuse.org
- Update to version 3.22.1:
  + Allow writing to large USB drives.
* Mon Sep 19 2016 dimstar@opensuse.org
- Update to version 3.22.0:
  + Updated translations.
* Wed Sep 14 2016 zaitor@opensuse.org
- Update to version 3.21.92:
  + Fixes several build issues.
  + Updated translations.
- Drop gmw-add-missing-include.patch: Fixed upstream.
* Mon Aug 29 2016 zaitor@opensuse.org
- Update to version 3.21.91:
  + Fix a couple of Werror=format problems.
  + Check for authentication before copying.
  + Updated translations.
- Drop gnome-multi-writer-fix-build.patch: Fixed upstream.
- Add pkgconfig(polkit-gobject-1) BuildRequires: New dependency.
- Add gmw-add-missing-include.patch: Fix build, patch from upstream
  git.
* Mon Aug 15 2016 dimstar@opensuse.org
- Update to version 3.21.90:
  + Updated translations.
- Add gnome-multi-writer-fix-build.patch: Fix build on 32bit archs.
* Mon Mar 21 2016 dimstar@opensuse.org
- Update to version 3.20.0:
  + Updated translations.
* Tue Feb 16 2016 dimstar@opensuse.org
- Update to version 3.19.90:
  + Add proper text to the button during a copy operation.
* Wed Sep 30 2015 zaitor@opensuse.org
- Own %%{_datadir}/polkit-1 and subfolder for openSUSE Tumbleweed.
* Mon Sep 21 2015 dimstar@opensuse.org
- Update to version 3.18.0:
  + Updated translations.
* Wed Sep 16 2015 dimstar@opensuse.org
- Update to version 3.17.92:
  + Use g_autoptr() types from GLib and GUsb.
  + Updated translations.
* Wed Aug 19 2015 zaitor@opensuse.org
- Update to version 3.17.90:
  + Updated translations.
* Wed Jun 24 2015 dimstar@opensuse.org
- Own %%{_datadir}/appdata for openSUSE 42.
* Mon Mar 23 2015 dimstar@opensuse.org
- Update to version 3.16.0:
  + No changes.
* Mon Mar 16 2015 dimstar@opensuse.org
- Update to version 3.15.92:
  + Updated translations.
* Tue Mar  3 2015 dimstar@opensuse.org
- Update to version 3.15.91:
  + Updated translations.
* Fri Feb 13 2015 dimstar@opensuse.org
- Update to version 3.15.90:
  + Bugfixes:
  - Add hub quirks for all Plugable USB devices.
  + New features:
  - Optionally check that USB drives are indeed their advertised
    size.
  - Allow renaming hub labels from the UI.
- Add pkgconfig(gudev-1.0) BuildRequires: new dependency for the
  gnome-multi-writer-probe tool.
* Tue Jan 20 2015 badshah400@gmail.com
- Update to version 3.15.4:
  + Show the size next to the device name when the device is idle.
  + Bugs fixed:
  - Add a translatable version of a generic flash drive.
  - Add quirks for the 36 port MegaHub.
  - Don't proceed to the copy phase if unmounting failed.
  - Fix crash when libusb context creation fails.
  - Never use the USB platform ID for the hub label.
  - Support root hubs with bus numbers >= 8.
  - Try to get the icon name hint from UDisks.
  - Unmount all partitions when a device is inserted.
* Sat Jan 10 2015 dimstar@opensuse.org
- Add docbook-utils-minimal BuildRequires: enable building of the
  man pages.
* Fri Jan  9 2015 dimstar@opensuse.org
- Initial package, version 3.15.2.
